Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mapsme/omim.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorvng <viktor.govako@gmail.com>2015-08-28 15:11:26 +0300
committerAlex Zolotarev <alex@maps.me>2015-09-23 03:03:09 +0300
commit5eeafbfc08413039368690b219e6ed4a22e05b2e (patch)
treea6fd0a7d8ab90abccea74c5523e80afa719849c4 /indexer/feature_data.hpp
parent0654f329113d8e72fa3c478afe44162af2cd474d (diff)
[generator] Fixed subway processing for London and Rome.
Diffstat (limited to 'indexer/feature_data.hpp')
-rw-r--r--indexer/feature_data.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/indexer/feature_data.hpp b/indexer/feature_data.hpp
index 3d140e97b7..7cc4ad05cd 100644
--- a/indexer/feature_data.hpp
+++ b/indexer/feature_data.hpp
@@ -243,8 +243,8 @@ public:
inline void AddType(uint32_t t) { m_Types.push_back(t); }
/// Special function to replace a regular railway station type with
- /// the special one for the correspondent city.
- void SetRwStationType(char const * cityName);
+ /// the special subway type for the correspondent city.
+ void SetRwSubwayType(char const * cityName);
/// @param skipType2 Do not accumulate this type if skipType2 != 0.
/// '2' means 2-level type in classificator tree (also skip child types).